@@ -7,9 +7,7 @@ import copy
 import requests
 import functools
 
-_original_methods = {
-    method: getattr(requests, method) for method in ["get", "post", "head", "put", "delete", "options"]
-}
+_original_methods = dict([(method, getattr(requests, method)) for method in ["get", "post", "head", "put", "delete", "options"]])
 
 calls = []
 
